/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the Kowari Metadata Store.
 *
 * The Initial Developer of the Original Code is Plugged In Software Pty
 * Ltd (http://www.pisoftware.com, mailto:info@pisoftware.com). Portions
 * created by Plugged In Software Pty Ltd are Copyright (C) 2001,2002
 * Plugged In Software Pty Ltd. All Rights Reserved.
 *
 * Contributor(s): N/A.
 *
 * [NOTE: The text of this Exhibit A may differ slightly from the text
 * of the notices in the Source Code files of the Original Code. You
 * should use the text of this Exhibit A rather than the text found in the
 * Original Code Source Code for Your Modifications.]
 *
 */

package org.kowari.resolver.spi;

// Local packages
import org.kowari.server.*;
import org.kowari.query.QueryException;

/**
 * Local extensions to the session interface.
 *
 * Note: This interface is one of the first steps towards a generic server-side
 *       extension API.  Expect it to change in signifigant, non-backwards compatible
 *       ways.
 *
 * @created 2004-11-10
 *
 * @author Andrew Newman
 *
 * @version $Revision: 1.8 $
 *
 * @modified $Date: 2005/01/05 04:58:50 $ by $Author: newmana $
 *
 * @maintenanceAuthor $Author: newmana $
 *
 * @copyright &copy;2004 <a href="http://www.tucanatech.com/">Tucana
 *   Technology, Inc</a>
 *
 * @licence <a href="{@docRoot}/../../LICENCE">Mozilla Public License v1.1</a>
 */
public interface LocalSession extends Session {

  /**
   * Start's or resumes a transaction for an operation.
   *
   * Using start/finish TransactionalOperation ensures properly matched pairs of
   * begin/end and suspend/resume.
   *
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public void startTransactionalOperation(boolean needsWrite)
      throws QueryException;

  /**
   * Mark the current transaction for rollback due to an exception.
   *
   * @param throwable  the exception which caused the rollback
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public void rollbackTransactionalBlock(Throwable throwable)
      throws QueryException;

  /**
   * Ends's or suspends a transaction for an operation.
   *
   * Using start/finish TransactionalOperation ensures properly matched pairs of
   * begin/end and suspend/resume.
   *
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public void finishTransactionalOperation(String errorString)
      throws QueryException;

  /**
   * Resumes the previously suspended transaction from the current session.
   *
   * @throws QueryException Must be called outside the try/catch(Throwable) block
   * protecting the transaction.
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public void resumeTransactionalBlock() throws QueryException;

  /**
   * Suspends current transaction, storing it in session for latter resumption.
   *
   * @throws Throwable Must be called inside the try/catch(Throwable) block
   * protecting the transaction.
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public void suspendTransactionalBlock() throws Throwable;

  /**
   * Returns the current Resolver Session.
   *
   * @return the current resolver session.
   * @deprecated This should not be relied upon to create resolvers as this
   *     should go away.
   */
  public ResolverSession getResolverSession();
}
